@@ -18,7 +18,7 @@ from sphinx.util import logging
 from .launch import add_hub_urls
 from . import static as theme_static
 
-__version__ = "0.0.37"
+__version__ = "0.0.40"
 """sphinx-book-theme version"""
 
 SPHINX_LOGGER = logging.getLogger(__name__)
@@ -86,12 +86,16 @@ def find_url_relative_to_root(pagename, relative_page, path_docs_source):
 
     # Convert everything to paths for use later
     path_rel = Path(relative_page).with_suffix("")
-    path_parent = Path(pagename)  # pagename is relative to docs root
+    if relative_page.endswith(".html"):
+        # HTML file Sphinx builder
+        path_parent = Path(pagename).parent  # pagename is .html relative to docs root
+    else:
+        # DirHTML Sphinx builder.
+        path_parent = Path(pagename)  # pagename is the parent folder if dirhtml builder
+
     source_dir = Path(path_docs_source)
     # This should be the path to `relative_page`, relative to `pagename`
-    path_rel_from_page_dir = source_dir.joinpath(
-        path_parent.parent.joinpath(path_rel.parent)
-    )
+    path_rel_from_page_dir = source_dir.joinpath(path_parent.joinpath(path_rel.parent))
     path_from_page_dir = Path(os.path.abspath(path_rel_from_page_dir))
     page_rel_root = path_from_page_dir.relative_to(source_dir).joinpath(path_rel.name)
     return page_rel_root
@@ -115,10 +119,6 @@ def add_to_context(app, pagename, templatename, context, doctree):
         )
         toctree = bs(toc_sphinx, "html.parser")
 
-        # pair "current" with "active" since that's what we use w/ bootstrap
-        for li in toctree("li", {"class": "current"}):
-            li["class"].append("active")
-
         # Add the master_doc page as the first item if specified
         if with_home_page:
             # Pull metadata about the master doc
@@ -129,12 +129,14 @@ def add_to_context(app, pagename, templatename, context, doctree):
             if len(master_title) == 0:
                 raise ValueError(f"Landing page missing a title: {master_doc}")
             master_title = master_title[0].astext()
-
+            li_class = "toctree-l1"
+            if context["pagename"] == master_doc:
+                li_class += " current"
             # Insert it into our toctree
             ul_home = bs(
                 f"""
             <ul>
-                <li class="toctree-l1">
+                <li class="{li_class}">
                     <a href="{master_url}" class="reference internal">{master_title}</a>
                 </li>
             </ul>""",
@@ -142,28 +144,61 @@ def add_to_context(app, pagename, templatename, context, doctree):
             )
             toctree.insert(0, ul_home("ul")[0])
 
+        # pair "current" with "active" since that's what we use w/ bootstrap
+        for li in toctree("li", {"class": "current"}):
+            li["class"].append("active")
+
         # Add an icon for external links
         for a_ext in toctree("a", attrs={"class": ["external"]}):
             a_ext.append(
                 toctree.new_tag("i", attrs={"class": ["fas", "fa-external-link-alt"]})
             )
 
-        # Remove children of all top-level pages unless config says to expand them
-        expand_sections = config.html_theme_options.get("expand_sections", [])
-        if isinstance(expand_sections, str):
-            expand_sections = []
+        # get level specified in conf
+        navbar_level = int(context["theme_show_navbar_depth"])
 
-        for li in toctree("li", attrs={"class": "toctree-l1"}):
-            page_rel_root = find_url_relative_to_root(
-                pagename, li.find("a").attrs["href"], app.srcdir
-            )
-            if li.find("ul"):
-                do_collapse = (
-                    "active" not in li.attrs["class"]
-                    and str(page_rel_root) not in expand_sections
-                )
-                if do_collapse:
-                    li.find("ul").decompose()
+        # function to open/close list and add icon
+        def collapse_list(li, ul, level):
+            if ul:
+                li.attrs["class"] = li.attrs.get("class", []) + ["collapsible-parent"]
+                if level <= 0:
+                    ul.attrs["class"] = ul.attrs.get("class", []) + ["collapse-ul"]
+                    li.append(
+                        toctree.new_tag(
+                            "i", attrs={"class": ["fas", "fa-chevron-down"]}
+                        )
+                    )
+                else:
+                    # Icon won't show up unless captions are collapsed
+                    if not li.name == "p" and "caption" not in li["class"]:
+                        li.append(
+                            toctree.new_tag(
+                                "i", attrs={"class": ["fas", "fa-chevron-up"]}
+                            )
+                        )
+
+        # for top-level caption's collapse functionality
+        for para in toctree("p", attrs={"class": ["caption"]}):
+            ul = para.find_next_sibling()
+            collapse_list(para, ul, navbar_level)
+
+        # iterate through all the lists in the sideabar and open/close
+        def iterate_toc_li(li, level):
+            if hasattr(li, "name") and li.name == "li":
+                ul = li.find("ul")
+                collapse_list(li, ul, level)
+            if isinstance(li, list) or hasattr(li, "name"):
+                for entry in li:
+                    if isinstance(entry, str):
+                        continue
+                    if hasattr(entry, "name"):
+                        if entry.name == "li":
+                            iterate_toc_li(entry, level - 1)
+                        else:
+                            iterate_toc_li(entry, level)
+            return
+
+        iterate_toc_li(toctree, navbar_level)
 
         # Add bootstrap classes for first `ul` items
         for ul in toctree("ul", recursive=False):
@@ -281,6 +316,7 @@ def add_to_context(app, pagename, templatename, context, doctree):
         "theme_use_edit_page_button",
         "theme_use_repository_button",
         "theme_use_issues_button",
+        "theme_use_download_button",
     ]
     for key in btns:
         if key in context:
@@ -386,3 +422,11 @@ def setup(app: Sphinx):
     app.connect("html-page-context", add_to_context)
 
     app.add_directive("margin", Margin)
+
+    # Update templates for sidebar
+    app.config.templates_path.append(os.path.join(package_dir, "_templates"))
+
+    return {
+        "parallel_read_safe": True,
+        "parallel_write_safe": True,
+    }
